@@ -271,7 +271,7 @@ function LStemplate_smarty_tr($params) {
 
 function LStemplate_smarty_img($params) {
   extract($params);
-  echo LStemplate :: getImagePath($name);
+  echo "image.php?i=$name";
 }
 
 // Errors
